@@ -16,10 +16,12 @@
 import click
 from dateutil import tz
 
-from zenml.core.repo.global_config import GlobalConfig
+from zenml.repo import Repository, GlobalConfig
 
 pass_config = click.make_pass_decorator(GlobalConfig, ensure=True)
 
+pass_repo = click.make_pass_decorator(Repository, ensure=True)
+
 
 def title(text):
     """
@@ -82,6 +84,14 @@ def warning(text):
     click.echo(click.style(text, fg='yellow', bold=True))
 
 
+def pretty_print(obj):
+    """
+    Args:
+        obj:
+    """
+    click.echo(str(obj))
+
+
 def format_date(dt, format='%Y-%m-%d %H:%M:%S'):
     """
     Args:
