@@ -29,10 +29,10 @@ from tensorflow_metadata.proto.v0 import statistics_pb2
 from tensorflow_transform.tf_metadata import schema_utils
 from tfx.utils import io_utils
 
-from zenml.utils.constants import APP_NAME, EVALUATION_NOTEBOOK, \
+from zenml.constants import APP_NAME, EVALUATION_NOTEBOOK, \
     COMPARISON_NOTEBOOK
-from zenml.utils.enums import GDPComponent
-from zenml.utils.logger import get_logger
+from zenml.enums import GDPComponent
+from zenml.logger import get_logger
 from zenml.utils.path_utils import read_file_contents
 
 logger = get_logger(__name__)
@@ -329,11 +329,8 @@ def evaluate_single_pipeline(
         os.system('jupyter notebook "{}"'.format(final_out_path))
 
 
-def compare_multiple_pipelines():
-    """
-    Args:
-        workspace_id (Text):
-    """
+def launch_compare_tool():
+    """Launches `compare` tool for comparing multiple training pipelines."""
     # assumes compare.py in the same folder
     template = \
         os.path.join(os.path.abspath(os.path.dirname(__file__)), 'compare.py')
