@@ -18,11 +18,10 @@ from typing import Text, Type, Optional, Union
 
 from tfx.utils.import_utils import import_class_by_path
 
-from zenml.core.repo.git_wrapper import GitWrapper
-from zenml.core.repo.repo import Repository
-from zenml.utils.constants import APP_NAME
-from zenml.utils.logger import get_logger
-from zenml.utils.version import __version__
+from zenml.repo import Repository, GitWrapper
+from zenml.constants import APP_NAME
+from zenml.logger import get_logger
+from zenml.version import __version__
 
 logger = get_logger(__name__)
 
@@ -221,3 +220,17 @@ def load_source_path_class(source_path: Text) -> Type:
         class_ = import_class_by_path(source)
 
     return class_
+
+
+def is_source(source_path: Text) -> bool:
+    """
+    Checks whether the source_path is source or not.
+
+    Args:
+        source_path (str): relative module path e.g. this.module.Class[@sha]
+    """
+    try:
+        load_source_path_class(source_path)
+    except:
+        return False
+    return True
